@@ -24,7 +24,7 @@ function(fit, q, d = "best", w = 1){
 		         to = max(qx.individual[i,]) +
 		           abs(0.001 * max(qx.individual[i,])), length = 10000)
 		px <- plinearpool(fit, x, d, w)
-		qx[i] <- approx(x = px, y = x, xout = q[i])$y 
+		qx[i] <- approx(x = px, y = x, xout = q[i], ties = min)$y 
 	}
 qx			
 }
